## cdist-type__install_bootloader_grub(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__install_bootloader_grub - install grub2 bootloader on given disk

## 2. DESCRIPTION

This cdist type allows you to install grub2 bootloader on given disk.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

device
  The device to install grub to. Defaults to object_id
chroot
  where to chroot before running grub-install. Defaults to /target.

## 5. EXAMPLES

    __install_bootloader_grub /dev/sda
    __install_bootloader_grub /dev/sda --chroot /mnt/foobar

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2011 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).